### Biofinormatics treatment for metabarcoding datasets under Mothur  ###
#   Tragin et al. 2016 
####


set.dir(input=/projet/sbr/osd/pathtoinputfiles, output=/projet/sbr/osd/pathtooutputfiles) 


# database cleaning

unique.seqs(fasta=database.fasta)
list.seqs(fasta=database.unique.fasta)
get.seqs(accnos=database.unique.accnos,taxonomy=database.taxo)


# ref alignment SILVA
summary.seqs(fasta=/projet/sbr/osd/database/silva.seed_v119.Euk.V2.align)


# Sub sampling dataset
       #-----Stations------#
get.groups(fasta=dataset.fasta, group=dataset.groups, groups=OSD123-OSD132-OSD49-OSD99-OSD77-OSD76-OSD22-OSD14-OSD146-OSD80-OSD141-OSD30-OSD72-OSD3-OSD2-OSD159-OSD152-OSD55-OSD54-OSD60-OSD39-OSD143-OSD37-OSD149-OSD150-OSD43-OSD124)
       
	   #-----Reads------#
sub.sample(fasta=dataset.pick.fasta, size=202710, group=dataset.pick.groups, persample=T)

# dataset
unique.seqs(fasta=dataset.fasta)
summary.seqs(fasta=dataset.unique.fasta)

count.seqs(name=dataset.names, group=dataset.groups, processors=1)
split.abund(count=dataset.count_table, fasta=dataset.unique.fasta, cutoff=1, accnos=T)  
screen.seqs(fasta=datasetV4.unique.abund.fasta, minlength=170, maxambig=0, count=dataset.abund.count_table)             #V4 length filter
screen.seqs(fasta=datasetV9.unique.abund.fasta, minlength=90, maxambig=0, count=dataset.abund.count_table)              #V9 length filter


# align to SILVA and filter
align.seqs(fasta=dataset.unique.abund.good.fasta, reference=/projet/sbr/osd/database/silva.seed_v119.Euk.pcr.V2.align, flip=T, processors=1)
filter.seqs(fasta=dataset.unique.abund.good.align)
unique.seqs(fasta=dataset.unique.abund.good.filter.fasta, count=dataset.abund.good.count_table)

# Preclustering and Chimeras checking
pre.cluster(fasta=dataset.unique.abund.good.filter.unique.fasta, count=dataset.unique.abund.good.filter.count_table, diffs=2, processors=1)

chimera.uchime(fasta=dataset.unique.abund.good.filter.unique.precluster.fasta, count=dataset.unique.abund.good.filter.unique.precluster.count_table, processors=1)
remove.seqs(fasta=dataset.unique.abund.good.filter.unique.precluster.fasta, accnos=dataset.unique.abund.good.filter.unique.precluster.uchime.accnos, count=dataset.unique.abund.good.filter.unique.precluster.count_table)



# classification with PR²
split.abund(count=dataset.unique.abund.good.filter.unique.precluster.pick.count_table, fasta=dataset.unique.abund.good.filter.unique.precluster.pick.fasta, cutoff=1, accnos=T)
classify.seqs(fasta=dataset.unique.abund.good.filter.unique.precluster.pick.abund.fasta, count=dataset.unique.abund.good.filter.unique.precluster.pick.abund.count_table, template=database.unique.fasta, taxonomy=database.pick.taxo, processors=1, probs=T) 

summary.tax(taxonomy=dataset.unique.abund.good.filter.unique.precluster.pick.abund.pick.wang.taxonomy, count=dataset.unique.abund.good.filter.unique.precluster.pick.abund.count_table)


# Cluster and OTUs
unique.seqs(fasta=dataset.unique.abund.good.filter.unique.precluster.pick.abund.fasta, count=dataset.unique.abund.good.filter.unique.precluster.pick.abund.count_table)  

dist.seqs(fasta=dataset.unique.abund.good.filter.unique.precluster.pick.abund.unique.good.fasta, cutoff=0.05, countends=F, processors=1)
cluster(column=dataset.unique.abund.good.filter.unique.precluster.pick.abund.unique.good.dist, count=dataset.unique.abund.good.filter.unique.precluster.pick.abund.unique.good.count_table, method=nearest)

make.shared(list=dataset.unique.abund.good.filter.unique.precluster.pick.abund.unique.good.nn.unique_list.list, count=dataset.unique.abund.good.filter.unique.precluster.pick.abund.unique.good.count_table, label=0.03)

classify.otu(taxonomy=dataset.unique.abund.good.filter.unique.precluster.pick.abund.pick.wang.taxonomy, count=dataset.unique.abund.good.filter.unique.precluster.pick.abund.unique.good.count_table, list=dataset.unique.abund.good.filter.unique.precluster.pick.abund.unique.good.nn.unique_list.list, label=0.03, probs=F, basis=sequence)

get.oturep(fasta=dataset.unique.abund.good.filter.unique.precluster.pick.abund.unique.good.fasta, column=dataset.unique.abund.good.filter.unique.precluster.pick.abund.unique.good.dist, count=dataset.unique.abund.good.filter.unique.precluster.pick.abund.unique.good.count_table, list=dataset.unique.abund.good.filter.unique.precluster.pick.abund.unique.good.nn.unique_list.list, cutoff=0.03, sorted=number)

create.database(shared=dataset.unique.abund.good.filter.unique.precluster.pick.abund.unique.good.nn.unique_list.shared, label=0.03, repfasta=dataset.unique.abund.good.filter.unique.precluster.pick.abund.unique.good.nn.unique_list.0.03.rep.fasta, count=dataset.unique.abund.good.filter.unique.precluster.pick.abund.unique.good.nn.unique_list.0.03.rep.count_table, constaxonomy=dataset.unique.abund.good.filter.unique.precluster.pick.abund.unique.good.nn.unique_list.0.03.cons.taxonomy)


